@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
 
 # Copyright 2018 The Knative Authors
 #
@@ -16,7 +16,7 @@
 
 set -o pipefail
 
-source_dirs="cmd pkg test lib"
+source_dirs="cmd pkg test lib tools"
 
 # Store for later
 if [ -z "$1" ]; then
@@ -98,6 +98,9 @@ codegen() {
   # Format source code and cleanup imports
   source_format
 
+  # Lint source code
+  (( ! IS_PROW )) && source_lint
+
   # Check for license headers
   check_license
 
@@ -110,23 +113,6 @@ go_fmt() {
   find $(echo $source_dirs) -name "*.go" -print0 | xargs -0 gofmt -s -w
 }
 
-# Run a go tool, get it first if necessary.
-run_go_tool() {
-  local tool=$2
-  local install_failed=0
-  if [ -z "$(which ${tool})" ]; then
-    local temp_dir="$(mktemp -d)"
-    pushd "${temp_dir}" > /dev/null 2>&1
-    GOFLAGS="" go get "$1" || install_failed=1
-    popd > /dev/null 2>&1
-    rm -rf "${temp_dir}"
-  fi
-  (( install_failed )) && return ${install_failed}
-  shift 2
-  ${tool} "$@"
-}
-
-
 source_format() {
   set +e
   run_go_tool golang.org/x/tools/cmd/goimports goimports -w $(echo $source_dirs)
@@ -134,6 +120,12 @@ source_format() {
   set -e
 }
 
+source_lint() {
+  echo "🔍 Lint"
+  run_go_tool github.com/golangci/golangci-lint/cmd/golangci-lint golangci-lint run  || \
+  { echo "--- FAIL: golangci-lint failed please fix the reported errors"; return 1; }
+}
+
 go_build() {
   echo "🚧 Compile"
   go build -mod=vendor -ldflags "$(build_flags $(basedir))" -o kn ./cmd/...
@@ -279,6 +271,8 @@ cross_build() {
   GOOS=linux GOARCH=arm64 go build -mod=vendor -ldflags "${ld_flags}" -o ./kn-linux-arm64 ./cmd/... || failed=1
   echo "   🍏 kn-darwin-amd64"
   GOOS=darwin GOARCH=amd64 go build -mod=vendor -ldflags "${ld_flags}" -o ./kn-darwin-amd64 ./cmd/... || failed=1
+  echo "   🍎 kn-darwin-arm64"
+  GOOS=darwin GOARCH=arm64 go build -mod=vendor -ldflags "${ld_flags}" -o ./kn-darwin-arm64 ./cmd/... || failed=1
   echo "   🎠 kn-windows-amd64.exe"
   GOOS=windows GOARCH=amd64 go build -mod=vendor -ldflags "${ld_flags}" -o ./kn-windows-amd64.exe ./cmd/... || failed=1
   echo "   Z  kn-linux-s390x"
@@ -351,6 +345,9 @@ if $(has_flag --debug); then
     set -x
 fi
 
+# Shared funcs from hack repo
+source $(basedir)/vendor/knative.dev/hack/library.sh
+
 # Shared funcs with CI
 source $(basedir)/hack/build-flags.sh
 
