@@ -18,8 +18,11 @@ package tools
 // This package imports things required by this repository, to force `go mod` to see them as dependencies
 import (
 	_ "knative.dev/hack"
+	_ "knative.dev/pkg/hack"
 
 	_ "k8s.io/code-generator"
 	_ "k8s.io/code-generator/cmd/deepcopy-gen"
 	_ "knative.dev/serving/test/test_images/grpc-ping"
+	_ "knative.dev/serving/test/test_images/multicontainer/servingcontainer"
+	_ "knative.dev/serving/test/test_images/multicontainer/sidecarcontainer"
 )
