@@ -15,6 +15,7 @@
 package errors
 
 import (
+	"errors"
 	"net/http"
 	"strings"
 
@@ -39,6 +40,27 @@ func isEmptyConfigError(err error) bool {
 	return strings.Contains(err.Error(), "no configuration has been provided")
 }
 
+func isStatusError(err error) bool {
+	var errAPIStatus api_errors.APIStatus
+	return errors.As(err, &errAPIStatus)
+}
+
+func newStatusError(err error) error {
+	var errAPIStatus api_errors.APIStatus
+	errors.As(err, &errAPIStatus)
+
+	if errAPIStatus.Status().Details == nil {
+		return err
+	}
+	var knerr *KNError
+	if isCRDError(errAPIStatus) {
+		knerr = newInvalidCRD(errAPIStatus.Status().Details.Group)
+		knerr.Status = errAPIStatus
+		return knerr
+	}
+	return err
+}
+
 //Retrieves a custom error struct based on the original error APIStatus struct
 //Returns the original error struct in case it can't identify the kind of APIStatus error
 func GetError(err error) error {
@@ -47,32 +69,22 @@ func GetError(err error) error {
 	}
 
 	switch {
+	case isStatusError(err):
+		return newStatusError(err)
 	case isEmptyConfigError(err):
 		return newNoKubeConfig(err.Error())
 	case isNoRouteToHostError(err):
 		return newNoRouteToHost(err.Error())
 	default:
-		apiStatus, ok := err.(api_errors.APIStatus)
-		if !ok {
-			return err
-		}
-		if apiStatus.Status().Details == nil {
-			return err
-		}
-		var knerr *KNError
-		if isCRDError(apiStatus) {
-			knerr = newInvalidCRD(apiStatus.Status().Details.Group)
-			knerr.Status = apiStatus
-			return knerr
-		}
 		return err
 	}
 }
 
 // IsForbiddenError returns true if given error can be converted to API status and of type forbidden access else false
 func IsForbiddenError(err error) bool {
-	if status, ok := err.(api_errors.APIStatus); ok {
-		return status.Status().Code == int32(http.StatusForbidden)
+	var errAPIStatus api_errors.APIStatus
+	if !errors.As(err, &errAPIStatus) {
+		return false
 	}
-	return false
+	return errAPIStatus.Status().Code == int32(http.StatusForbidden)
 }
