@@ -57,7 +57,7 @@ func NewRevisionDescribeCommand(p *commands.KnParams) *cobra.Command {
 				return err
 			}
 
-			revision, err := client.GetRevision(args[0])
+			revision, err := client.GetRevision(cmd.Context(), args[0])
 			if err != nil {
 				return err
 			}
@@ -76,7 +76,7 @@ func NewRevisionDescribeCommand(p *commands.KnParams) *cobra.Command {
 			var service *servingv1.Service
 			serviceName, ok := revision.Labels[serving.ServiceLabelKey]
 			if printDetails && ok {
-				service, err = client.GetService(serviceName)
+				service, err = client.GetService(cmd.Context(), serviceName)
 				if err != nil {
 					return err
 				}
@@ -96,6 +96,7 @@ func describe(w io.Writer, revision *servingv1.Revision, service *servingv1.Serv
 	dw := printers.NewPrefixWriter(w)
 	commands.WriteMetadata(dw, &revision.ObjectMeta, printDetails)
 	WriteImage(dw, revision)
+	WriteReplicas(dw, revision)
 	WritePort(dw, revision)
 	WriteEnv(dw, revision, printDetails)
 	WriteEnvFrom(dw, revision, printDetails)
@@ -152,8 +153,8 @@ func WriteConcurrencyOptions(dw printers.PrefixWriter, revision *servingv1.Revis
 
 // Write the image attribute (with
 func WriteImage(dw printers.PrefixWriter, revision *servingv1.Revision) {
-	c, err := clientserving.ContainerOfRevisionSpec(&revision.Spec)
-	if err != nil {
+	c := clientserving.ContainerOfRevisionSpec(&revision.Spec)
+	if c == nil {
 		dw.WriteAttribute("Image", "Unknown")
 		return
 	}
@@ -202,6 +203,14 @@ func WriteEnvFrom(dw printers.PrefixWriter, revision *servingv1.Revision, printD
 	}
 }
 
+func WriteReplicas(dw printers.PrefixWriter, revision *servingv1.Revision) {
+	actualReplicas := revision.Status.ActualReplicas
+	desiredReplicas := revision.Status.DesiredReplicas
+	if actualReplicas != nil && desiredReplicas != nil {
+		dw.WriteAttribute("Replicas", fmt.Sprintf("%d/%d", *actualReplicas, *desiredReplicas))
+	}
+}
+
 func WriteScale(dw printers.PrefixWriter, revision *servingv1.Revision) {
 	// Scale spec if given
 	scale, err := clientserving.ScalingInfo(&revision.ObjectMeta)
@@ -214,8 +223,8 @@ func WriteScale(dw printers.PrefixWriter, revision *servingv1.Revision) {
 }
 
 func WriteResources(dw printers.PrefixWriter, r *servingv1.Revision) {
-	c, err := clientserving.ContainerOfRevisionSpec(&r.Spec)
-	if err != nil {
+	c := clientserving.ContainerOfRevisionSpec(&r.Spec)
+	if c == nil {
 		return
 	}
 	requests := c.Resources.Requests
@@ -271,8 +280,8 @@ func formatScale(minScale *int, maxScale *int) string {
 }
 
 func stringifyEnv(revision *servingv1.Revision) []string {
-	container, err := clientserving.ContainerOfRevisionSpec(&revision.Spec)
-	if err != nil {
+	container := clientserving.ContainerOfRevisionSpec(&revision.Spec)
+	if container == nil {
 		return nil
 	}
 
@@ -288,8 +297,8 @@ func stringifyEnv(revision *servingv1.Revision) []string {
 }
 
 func stringifyEnvFrom(revision *servingv1.Revision) []string {
-	container, err := clientserving.ContainerOfRevisionSpec(&revision.Spec)
-	if err != nil {
+	container := clientserving.ContainerOfRevisionSpec(&revision.Spec)
+	if container == nil {
 		return nil
 	}
 
