@@ -48,7 +48,12 @@ var updateExample = `
   kn service update svc --untag testing --tag @latest=staging
 
   # Add tag 'test' to echo-v3 revision with 10% traffic and rest to latest ready revision of service
-  kn service update svc --tag echo-v3=test --traffic test=10,@latest=90`
+  kn service update svc --tag echo-v3=test --traffic test=10,@latest=90
+
+  # Update the service in offline mode instead of kubernetes cluster
+  kn service update gitopstest -n test-ns --env KEY1=VALUE1 --target=/user/knfiles
+  kn service update gitopstest --env KEY1=VALUE1 --target=/user/knfiles/test.yaml
+  kn service update gitopstest --env KEY1=VALUE1 --target=/user/knfiles/test.json`
 
 func NewServiceUpdateCommand(p *commands.KnParams) *cobra.Command {
 	var editFlags ConfigurationEditFlags
@@ -67,8 +72,8 @@ func NewServiceUpdateCommand(p *commands.KnParams) *cobra.Command {
 			if err != nil {
 				return err
 			}
-
-			client, err := p.NewServingClient(namespace)
+			targetFlag := cmd.Flag("target").Value.String()
+			client, err := newServingClient(p, namespace, targetFlag)
 			if err != nil {
 				return err
 			}
@@ -80,9 +85,10 @@ func NewServiceUpdateCommand(p *commands.KnParams) *cobra.Command {
 			updateFunc := func(service *servingv1.Service) (*servingv1.Service, error) {
 				latestRevisionBeforeUpdate = service.Status.LatestReadyRevisionName
 				var baseRevision *servingv1.Revision
-				if !cmd.Flags().Changed("image") && editFlags.LockToDigest {
-					baseRevision, err = client.GetBaseRevision(service)
-					if _, ok := err.(*clientservingv1.NoBaseRevisionError); ok {
+				if isImagePinned(cmd, editFlags) {
+					baseRevision, err = client.GetBaseRevision(cmd.Context(), service)
+					var errNoBaseRevision clientservingv1.NoBaseRevisionError
+					if errors.As(err, &errNoBaseRevision) {
 						fmt.Fprintf(cmd.OutOrStdout(), "Warning: No revision found to update image digest")
 					}
 				}
@@ -103,21 +109,28 @@ func NewServiceUpdateCommand(p *commands.KnParams) *cobra.Command {
 			}
 
 			// Do the actual update with retry in case of conflicts
-			err = client.UpdateServiceWithRetry(name, updateFunc, MaxUpdateRetries)
+			changed, err := client.UpdateServiceWithRetry(cmd.Context(), name, updateFunc, MaxUpdateRetries)
 			if err != nil {
 				return err
 			}
-
 			out := cmd.OutOrStdout()
-			if waitFlags.Wait {
+
+			// No need to wait if not changed
+			if !changed {
+				fmt.Fprintf(out, "Service '%s' updated in namespace '%s'.\n", args[0], namespace)
+				fmt.Fprintln(out, "No new revision has been created.")
+				return nil
+			}
+
+			if waitFlags.Wait && targetFlag == "" {
 				fmt.Fprintf(out, "Updating Service '%s' in namespace '%s':\n", args[0], namespace)
 				fmt.Fprintln(out, "")
-				err := waitForService(client, name, out, waitFlags.TimeoutInSeconds)
+				err := waitForService(cmd.Context(), client, name, out, waitFlags.TimeoutInSeconds)
 				if err != nil {
 					return err
 				}
 				fmt.Fprintln(out, "")
-				return showUrl(client, name, latestRevisionBeforeUpdate, "updated", out)
+				return showUrl(cmd.Context(), client, name, latestRevisionBeforeUpdate, "updated", out)
 			} else {
 				fmt.Fprintf(out, "Service '%s' updated in namespace '%s'.\n", args[0], namespace)
 			}
@@ -126,18 +139,23 @@ func NewServiceUpdateCommand(p *commands.KnParams) *cobra.Command {
 
 		},
 		PreRunE: func(cmd *cobra.Command, args []string) error {
-			return preCheck(cmd, args)
+			return preCheck(cmd)
 		},
 	}
 
 	commands.AddNamespaceFlags(serviceUpdateCommand.Flags(), false)
+	commands.AddGitOpsFlags(serviceUpdateCommand.Flags())
 	editFlags.AddUpdateFlags(serviceUpdateCommand)
 	waitFlags.AddConditionWaitFlags(serviceUpdateCommand, commands.WaitDefaultTimeout, "update", "service", "ready")
 	trafficFlags.Add(serviceUpdateCommand)
 	return serviceUpdateCommand
 }
 
-func preCheck(cmd *cobra.Command, args []string) error {
+func isImagePinned(cmd *cobra.Command, editFlags ConfigurationEditFlags) bool {
+	return !cmd.Flags().Changed("image") && editFlags.LockToDigest
+}
+
+func preCheck(cmd *cobra.Command) error {
 	if cmd.Flags().NFlag() == 0 {
 		return fmt.Errorf("flag(s) not set\nUsage: %s", cmd.Use)
 	}
