@@ -17,13 +17,14 @@ package service
 import (
 	"errors"
 	"fmt"
+	"os"
 	"reflect"
 	"strings"
 	"testing"
 	"time"
 
-	"gotest.tools/assert"
-	"gotest.tools/assert/cmp"
+	"gotest.tools/v3/assert"
+	"gotest.tools/v3/assert/cmp"
 
 	"knative.dev/client/pkg/kn/commands"
 	servinglib "knative.dev/client/pkg/serving"
@@ -62,10 +63,12 @@ func fakeServiceUpdate(original *servingv1.Service, args []string) (
 			if !ok {
 				return true, nil, fmt.Errorf("wrong kind of action %v", action)
 			}
-			updated, ok = updateAction.GetObject().(*servingv1.Service)
+			given, ok := updateAction.GetObject().(*servingv1.Service)
 			if !ok {
 				return true, nil, errors.New("was passed the wrong object")
 			}
+			updated = given.DeepCopy()
+			updated.Generation = given.Generation + 1
 			return true, updated, nil
 		})
 	fakeServing.AddReactor("get", "services",
@@ -90,6 +93,10 @@ func fakeServiceUpdate(original *servingv1.Service, args []string) (
 			rev.Spec = original.Spec.Template.Spec
 			rev.ObjectMeta = original.Spec.Template.ObjectMeta
 			rev.Name = original.Status.LatestCreatedRevisionName
+			rev.Status.ContainerStatuses = []servingv1.ContainerStatus{
+				{ImageDigest: exampleImageByDigest, Name: "user-container"},
+			}
+
 			rev.Status.DeprecatedImageDigest = exampleImageByDigest
 			return true, rev, nil
 		})
@@ -180,11 +187,8 @@ func TestServiceUpdateImage(t *testing.T) {
 	}
 
 	template = &updated.Spec.Template
-	container, err := servinglib.ContainerOfRevisionTemplate(template)
-	if err != nil {
-		t.Fatal(err)
-	}
-	assert.Equal(t, container.Image, "gcr.io/foo/quux:xyzzy")
+	container := servinglib.ContainerOfRevisionSpec(&template.Spec)
+	assert.Assert(t, container != nil && container.Image == "gcr.io/foo/quux:xyzzy")
 
 	if !strings.Contains(strings.ToLower(output), "update") ||
 		!strings.Contains(output, "foo") ||
@@ -193,6 +197,14 @@ func TestServiceUpdateImage(t *testing.T) {
 		!strings.Contains(output, "bar") {
 		t.Fatalf("wrong or no success message: %s", output)
 	}
+
+	assert.Assert(t, template.Annotations != nil)
+	ts := template.Annotations[servinglib.UpdateTimestampAnnotationKey]
+	assert.Assert(t, ts != "")
+	updateTs, err := time.Parse(time.RFC3339, ts)
+	assert.NilError(t, err)
+	assert.Assert(t, updateTs.Before(time.Now()))
+	assert.Assert(t, updateTs.After(time.Now().Add(-5*time.Second)))
 }
 
 func TestServiceUpdateWithMultipleImages(t *testing.T) {
@@ -216,7 +228,7 @@ func TestServiceUpdateCommand(t *testing.T) {
 
 	origTemplate := &orig.Spec.Template
 
-	err := flags.UpdateContainerCommand(&origTemplate.Spec.PodSpec, "./start")
+	err := flags.UpdateContainerCommand(&origTemplate.Spec.PodSpec, []string{"./start"})
 	assert.NilError(t, err)
 
 	action, updated, _, err := fakeServiceUpdate(orig, []string{
@@ -271,7 +283,7 @@ func TestServiceUpdateRevisionNameGenerated(t *testing.T) {
 
 	// Test prefix added by command
 	action, updated, _, err := fakeServiceUpdate(orig, []string{
-		"service", "update", "foo", "--image", "gcr.io/foo/quux:xyzzy", "--namespace", "bar", "--no-wait"})
+		"service", "update", "foo", "--image", "gcr.io/foo/quux:xyzzy", "--namespace", "bar", "--no-wait", "--revision-name", "{{.Service}}-{{.Random 5}}-{{.Generation}}"})
 	assert.NilError(t, err)
 	if !action.Matches("update", "services") {
 		t.Fatalf("Bad action %v", action)
@@ -282,6 +294,24 @@ func TestServiceUpdateRevisionNameGenerated(t *testing.T) {
 	assert.Assert(t, !(template.Name == "foo-asdf"))
 }
 
+func TestServiceUpdateRevisionNameDefault(t *testing.T) {
+	orig := newEmptyService()
+
+	template := orig.Spec.Template
+	template.Name = "foo-asdf"
+
+	// Test prefix added by command
+	action, updated, _, err := fakeServiceUpdate(orig, []string{
+		"service", "update", "foo", "--image", "gcr.io/foo/quux:xyzzy"})
+	assert.NilError(t, err)
+	if !action.Matches("update", "services") {
+		t.Fatalf("Bad action %v", action)
+	}
+
+	template = updated.Spec.Template
+	assert.Assert(t, cmp.Equal(template.Name, ""))
+}
+
 func TestServiceUpdateRevisionNameCleared(t *testing.T) {
 	orig := newEmptyService()
 
@@ -332,9 +362,6 @@ func TestServiceUpdateMaxMinScale(t *testing.T) {
 	}
 
 	template := updated.Spec.Template
-	if err != nil {
-		t.Fatal(err)
-	}
 
 	actualAnnos := template.Annotations
 	expectedAnnos := []string{
@@ -372,9 +399,6 @@ func TestServiceUpdateScale(t *testing.T) {
 	}
 
 	template := updated.Spec.Template
-	if err != nil {
-		t.Fatal(err)
-	}
 
 	actualAnnos := template.Annotations
 	expectedAnnos := []string{
@@ -448,6 +472,173 @@ func TestServiceUpdateScaleWithMinScaleSet(t *testing.T) {
 	}
 
 }
+
+func TestServiceUpdateScaleWithRange(t *testing.T) {
+	original := newEmptyService()
+
+	action, updated, _, err := fakeServiceUpdate(original, []string{
+		"service", "update", "foo",
+		"--scale", "1..5", "--no-wait"})
+
+	if err != nil {
+		t.Fatal(err)
+	} else if !action.Matches("update", "services") {
+		t.Fatal("Bad action ", action)
+	}
+
+	template := updated.Spec.Template
+
+	actualAnnos := template.Annotations
+	expectedAnnos := []string{
+		"autoscaling.knative.dev/minScale", "1",
+		"autoscaling.knative.dev/maxScale", "5",
+	}
+
+	for i := 0; i < len(expectedAnnos); i += 2 {
+		anno := expectedAnnos[i]
+		if actualAnnos[anno] != expectedAnnos[i+1] {
+			t.Fatalf("Unexpected annotation value for %s : %s (actual) != %s (expected)",
+				anno, actualAnnos[anno], expectedAnnos[i+1])
+		}
+	}
+
+}
+
+func TestServiceUpdateScaleMinWithRange(t *testing.T) {
+	original := newEmptyService()
+
+	action, updated, _, err := fakeServiceUpdate(original, []string{
+		"service", "update", "foo",
+		"--scale", "1..", "--no-wait"})
+
+	if err != nil {
+		t.Fatal(err)
+	} else if !action.Matches("update", "services") {
+		t.Fatal("Bad action ", action)
+	}
+
+	template := updated.Spec.Template
+
+	actualAnnos := template.Annotations
+	expectedAnnos := []string{
+		"autoscaling.knative.dev/minScale", "1",
+	}
+
+	for i := 0; i < len(expectedAnnos); i += 2 {
+		anno := expectedAnnos[i]
+		if actualAnnos[anno] != expectedAnnos[i+1] {
+			t.Fatalf("Unexpected annotation value for %s : %s (actual) != %s (expected)",
+				anno, actualAnnos[anno], expectedAnnos[i+1])
+		}
+	}
+
+}
+
+func TestServiceUpdateScaleMinWithRangeNegative(t *testing.T) {
+	original := newEmptyService()
+
+	_, _, _, err := fakeServiceUpdate(original, []string{
+		"service", "update", "foo",
+		"--scale", "-1..", "--no-wait"})
+
+	if err == nil {
+		t.Fatal("Expected error, got nil")
+	}
+
+	expectedErrMsg := "expected 0 <= -1 <= 2147483647: autoscaling.knative.dev/minScale"
+
+	if !strings.Contains(err.Error(), expectedErrMsg) {
+		t.Errorf("Invalid error output, expected: %s, got : '%s'", expectedErrMsg, err)
+	}
+
+}
+
+func TestServiceUpdateScaleMaxWithRange(t *testing.T) {
+	original := newEmptyService()
+
+	action, updated, _, err := fakeServiceUpdate(original, []string{
+		"service", "update", "foo",
+		"--scale", "..5", "--no-wait"})
+
+	if err != nil {
+		t.Fatal(err)
+	} else if !action.Matches("update", "services") {
+		t.Fatal("Bad action ", action)
+	}
+
+	template := updated.Spec.Template
+
+	actualAnnos := template.Annotations
+	expectedAnnos := []string{
+		"autoscaling.knative.dev/maxScale", "5",
+	}
+
+	for i := 0; i < len(expectedAnnos); i += 2 {
+		anno := expectedAnnos[i]
+		if actualAnnos[anno] != expectedAnnos[i+1] {
+			t.Fatalf("Unexpected annotation value for %s : %s (actual) != %s (expected)",
+				anno, actualAnnos[anno], expectedAnnos[i+1])
+		}
+	}
+
+}
+
+func TestServiceUpdateScaleMaxWithRangeNegative(t *testing.T) {
+	original := newEmptyService()
+
+	_, _, _, err := fakeServiceUpdate(original, []string{
+		"service", "update", "foo",
+		"--scale", "..-5", "--no-wait"})
+
+	if err == nil {
+		t.Fatal("Expected error, got nil")
+	}
+
+	expectedErrMsg := "expected 0 <= -5 <= 2147483647: autoscaling.knative.dev/maxScale"
+
+	if !strings.Contains(err.Error(), expectedErrMsg) {
+		t.Errorf("Invalid error output, expected: %s, got : '%s'", expectedErrMsg, err)
+	}
+
+}
+
+func TestServiceUpdateScaleRangeOnlyMinWrongSeparator(t *testing.T) {
+	original := newEmptyService()
+
+	_, _, _, err := fakeServiceUpdate(original, []string{
+		"service", "update", "foo",
+		"--scale", "1--", "--no-wait"})
+
+	if err == nil {
+		t.Fatal("Expected error, got nil")
+	}
+
+	expectedErrMsg := "Scale must be of the format x..y or x"
+
+	if !strings.Contains(err.Error(), expectedErrMsg) {
+		t.Errorf("Invalid error output, expected: %s, got : '%s'", expectedErrMsg, err)
+	}
+
+}
+
+func TestServiceUpdateScaleRangeOnlyMaxWrongSeparator(t *testing.T) {
+	original := newEmptyService()
+
+	_, _, _, err := fakeServiceUpdate(original, []string{
+		"service", "update", "foo",
+		"--scale", "--1", "--no-wait"})
+
+	if err == nil {
+		t.Fatal("Expected error, got nil")
+	}
+
+	expectedErrMsg := "Scale must be of the format x..y or x"
+
+	if !strings.Contains(err.Error(), expectedErrMsg) {
+		t.Errorf("Invalid error output, expected: %s, got : '%s'", expectedErrMsg, err)
+	}
+}
+
 func TestServiceUpdateEnv(t *testing.T) {
 	orig := newEmptyService()
 
@@ -459,8 +650,16 @@ func TestServiceUpdateEnv(t *testing.T) {
 
 	flags.UpdateImage(&template.Spec.PodSpec, "gcr.io/foo/bar:baz")
 
-	action, updated, _, err := fakeServiceUpdate(orig, []string{
-		"service", "update", "foo", "-e", "TARGET=Awesome", "--env", "EXISTING-", "--env=OTHEREXISTING-=whatever", "--no-wait"})
+	// we need to temporary reset os.Args, becase it is being used for evaluation
+	// of order of envs set by --env and --env-value-from
+	oldArgs := os.Args
+	defer func() { os.Args = oldArgs }()
+
+	args := []string{
+		"service", "update", "foo", "-e", "TARGET=Awesome", "--env", "EXISTING-", "--env", "OTHEREXISTING-", "--no-wait"}
+	os.Args = args
+
+	action, updated, _, err := fakeServiceUpdate(orig, args)
 
 	if err != nil {
 		t.Fatal(err)
@@ -575,7 +774,7 @@ func TestServiceUpdateDoesntPinToDigestWhenPreviouslyDidnt(t *testing.T) {
 }
 
 func TestServiceUpdateRequestsLimitsCPU(t *testing.T) {
-	service := createMockServiceWithResources(t, "250", "64Mi", "1000m", "1024Mi")
+	service := createMockServiceWithResources("250", "64Mi", "1000m", "1024Mi")
 
 	action, updated, _, err := fakeServiceUpdate(service, []string{
 		"service", "update", "foo", "--request", "cpu=500m", "--limit", "cpu=1000m", "--no-wait"})
@@ -595,25 +794,23 @@ func TestServiceUpdateRequestsLimitsCPU(t *testing.T) {
 	}
 
 	newTemplate := updated.Spec.Template
-	if err != nil {
-		t.Fatal(err)
-	} else {
-		if !reflect.DeepEqual(
-			newTemplate.Spec.Containers[0].Resources.Requests,
-			expectedRequestsVars) {
-			t.Fatalf("wrong requests vars %v", newTemplate.Spec.Containers[0].Resources.Requests)
-		}
 
-		if !reflect.DeepEqual(
-			newTemplate.Spec.Containers[0].Resources.Limits,
-			expectedLimitsVars) {
-			t.Fatalf("wrong limits vars %v", newTemplate.Spec.Containers[0].Resources.Limits)
-		}
+	if !reflect.DeepEqual(
+		newTemplate.Spec.Containers[0].Resources.Requests,
+		expectedRequestsVars) {
+		t.Fatalf("wrong requests vars %v", newTemplate.Spec.Containers[0].Resources.Requests)
 	}
+
+	if !reflect.DeepEqual(
+		newTemplate.Spec.Containers[0].Resources.Limits,
+		expectedLimitsVars) {
+		t.Fatalf("wrong limits vars %v", newTemplate.Spec.Containers[0].Resources.Limits)
+	}
+
 }
 
 func TestServiceUpdateRequestsLimitsMemory(t *testing.T) {
-	service := createMockServiceWithResources(t, "100m", "64Mi", "1000m", "1024Mi")
+	service := createMockServiceWithResources("100m", "64Mi", "1000m", "1024Mi")
 
 	action, updated, _, err := fakeServiceUpdate(service, []string{
 		"service", "update", "foo", "--request", "memory=128Mi", "--limit", "memory=2048Mi", "--no-wait"})
@@ -633,25 +830,22 @@ func TestServiceUpdateRequestsLimitsMemory(t *testing.T) {
 	}
 
 	newTemplate := updated.Spec.Template
-	if err != nil {
-		t.Fatal(err)
-	} else {
-		if !reflect.DeepEqual(
-			newTemplate.Spec.Containers[0].Resources.Requests,
-			expectedRequestsVars) {
-			t.Fatalf("wrong requests vars %v", newTemplate.Spec.Containers[0].Resources.Requests)
-		}
 
-		if !reflect.DeepEqual(
-			newTemplate.Spec.Containers[0].Resources.Limits,
-			expectedLimitsVars) {
-			t.Fatalf("wrong limits vars %v", newTemplate.Spec.Containers[0].Resources.Limits)
-		}
+	if !reflect.DeepEqual(
+		newTemplate.Spec.Containers[0].Resources.Requests,
+		expectedRequestsVars) {
+		t.Fatalf("wrong requests vars %v", newTemplate.Spec.Containers[0].Resources.Requests)
+	}
+
+	if !reflect.DeepEqual(
+		newTemplate.Spec.Containers[0].Resources.Limits,
+		expectedLimitsVars) {
+		t.Fatalf("wrong limits vars %v", newTemplate.Spec.Containers[0].Resources.Limits)
 	}
 }
 
 func TestServiceUpdateRequestsLimitsCPU_and_Memory(t *testing.T) {
-	service := createMockServiceWithResources(t, "250m", "64Mi", "1000m", "1024Mi")
+	service := createMockServiceWithResources("250m", "64Mi", "1000m", "1024Mi")
 
 	action, updated, _, err := fakeServiceUpdate(service, []string{
 		"service", "update", "foo",
@@ -673,30 +867,23 @@ func TestServiceUpdateRequestsLimitsCPU_and_Memory(t *testing.T) {
 	}
 
 	newTemplate := updated.Spec.Template
-	if err != nil {
-		t.Fatal(err)
-	} else {
-		if !reflect.DeepEqual(
-			newTemplate.Spec.Containers[0].Resources.Requests,
-			expectedRequestsVars) {
-			t.Fatalf("wrong requests vars %v", newTemplate.Spec.Containers[0].Resources.Requests)
-		}
+	if !reflect.DeepEqual(
+		newTemplate.Spec.Containers[0].Resources.Requests,
+		expectedRequestsVars) {
+		t.Fatalf("wrong requests vars %v", newTemplate.Spec.Containers[0].Resources.Requests)
+	}
 
-		if !reflect.DeepEqual(
-			newTemplate.Spec.Containers[0].Resources.Limits,
-			expectedLimitsVars) {
-			t.Fatalf("wrong limits vars %v", newTemplate.Spec.Containers[0].Resources.Limits)
-		}
+	if !reflect.DeepEqual(
+		newTemplate.Spec.Containers[0].Resources.Limits,
+		expectedLimitsVars) {
+		t.Fatalf("wrong limits vars %v", newTemplate.Spec.Containers[0].Resources.Limits)
 	}
 }
 
 func TestServiceUpdateLabelWhenEmpty(t *testing.T) {
 	original := newEmptyService()
 	origTemplate := original.Spec.Template
-	origContainer, err := servinglib.ContainerOfRevisionTemplate(&origTemplate)
-	if err != nil {
-		t.Fatal(err)
-	}
+	origContainer := servinglib.ContainerOfRevisionSpec(&origTemplate.Spec)
 	origContainer.Image = "gcr.io/foo/bar:latest"
 
 	action, updated, _, err := fakeServiceUpdate(original, []string{
@@ -719,11 +906,8 @@ func TestServiceUpdateLabelWhenEmpty(t *testing.T) {
 	template := updated.Spec.Template
 	actual = template.ObjectMeta.Labels
 	assert.DeepEqual(t, expected, actual)
-	container, err := servinglib.ContainerOfRevisionTemplate(&template)
-	if err != nil {
-		t.Fatal(err)
-	}
-	assert.Equal(t, container.Image, exampleImageByDigest)
+	container := servinglib.ContainerOfRevisionSpec(&template.Spec)
+	assert.Assert(t, container != nil && container.Image == exampleImageByDigest)
 }
 
 func TestServiceUpdateLabelExisting(t *testing.T) {
@@ -813,9 +997,6 @@ func TestServiceUpdateNoClusterLocalOnPrivateService(t *testing.T) {
 	assert.DeepEqual(t, expected, actual)
 
 	newTemplate := updated.Spec.Template
-	if err != nil {
-		t.Fatal(err)
-	}
 
 	actual = newTemplate.ObjectMeta.Labels
 	assert.DeepEqual(t, expected, actual)
@@ -860,7 +1041,7 @@ func newEmptyService() *servingv1.Service {
 	return ret
 }
 
-func createMockServiceWithResources(t *testing.T, requestCPU, requestMemory, limitsCPU, limitsMemory string) *servingv1.Service {
+func createMockServiceWithResources(requestCPU, requestMemory, limitsCPU, limitsMemory string) *servingv1.Service {
 	service := newEmptyService()
 
 	template := service.Spec.Template
