@@ -15,23 +15,24 @@
 package source
 
 import (
+	"context"
 	"strings"
 	"testing"
 
+	"knative.dev/client/pkg/dynamic/fake"
+
 	"gotest.tools/v3/assert"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/apimachinery/pkg/labels"
 	"k8s.io/apimachinery/pkg/runtime"
 
-	dynamicfake "k8s.io/client-go/dynamic/fake"
-	clientdynamic "knative.dev/client/pkg/dynamic"
 	"knative.dev/client/pkg/kn/commands"
 	"knative.dev/client/pkg/util"
 )
 
 const (
 	crdGroup          = "apiextensions.k8s.io"
-	crdVersion        = "v1beta1"
+	crdVersion        = "v1"
 	crdKind           = "CustomResourceDefinition"
 	sourcesLabelKey   = "duck.knative.dev/source"
 	sourcesLabelValue = "true"
@@ -58,20 +59,32 @@ func TestSourceListTypesNoSourcesInstalled(t *testing.T) {
 	assert.Check(t, util.ContainsAll(err.Error(), "no sources", "found", "backend", "verify", "installation"))
 }
 
+func TestSourceListTypesNoSourcesWithJsonOutput(t *testing.T) {
+	output, err := sourceFakeCmd([]string{"source", "list-types", "-o", "json"},
+		&unstructured.Unstructured{
+			Object: map[string]interface{}{
+				"apiVersion": "apiextensions.k8s.io/v1",
+				"kind":       "CustomResourceDefinitionList",
+			},
+		})
+	assert.NilError(t, err)
+	assert.Check(t, util.ContainsAll(strings.Join(output[:], "\n"), "\"apiVersion\": \"apiextensions.k8s.io/v1\"", "\"items\": []", "\"kind\": \"CustomResourceDefinitionList\""))
+}
+
 func TestSourceListTypes(t *testing.T) {
 	output, err := sourceFakeCmd([]string{"source", "list-types"},
-		newSourceCRDObjWithSpec("pingsources", "sources.knative.dev", "v1alpha1", "PingSource"),
-		newSourceCRDObjWithSpec("apiserversources", "sources.knative.dev", "v1alpha1", "ApiServerSource"),
+		newSourceCRDObjWithSpec("pingsources", "sources.knative.dev", "v1beta2", "PingSource"),
+		newSourceCRDObjWithSpec("apiserversources", "sources.knative.dev", "v1", "ApiServerSource"),
 	)
 	assert.NilError(t, err)
-	assert.Check(t, util.ContainsAll(output[0], "TYPE", "NAME", "DESCRIPTION"))
-	assert.Check(t, util.ContainsAll(output[1], "ApiServerSource", "apiserversources"))
-	assert.Check(t, util.ContainsAll(output[2], "PingSource", "pingsources"))
+	assert.Check(t, util.ContainsAll(output[0], "TYPE", "S", "NAME", "DESCRIPTION"))
+	assert.Check(t, util.ContainsAll(output[1], "ApiServerSource", "X", "apiserversources"))
+	assert.Check(t, util.ContainsAll(output[2], "PingSource", "X", "pingsources"))
 }
 
 func TestSourceListTypesNoHeaders(t *testing.T) {
 	output, err := sourceFakeCmd([]string{"source", "list-types", "--no-headers"},
-		newSourceCRDObjWithSpec("pingsources", "sources.knative.dev", "v1alpha1", "PingSource"),
+		newSourceCRDObjWithSpec("pingsources", "sources.knative.dev", "v1", "PingSource"),
 	)
 	assert.NilError(t, err)
 	assert.Check(t, util.ContainsNone(output[0], "TYPE", "NAME", "DESCRIPTION"))
@@ -79,8 +92,7 @@ func TestSourceListTypesNoHeaders(t *testing.T) {
 }
 
 func TestListBuiltInSourceTypes(t *testing.T) {
-	fakeDynamic := dynamicfake.NewSimpleDynamicClient(runtime.NewScheme())
-	sources, err := listBuiltInSourceTypes(clientdynamic.NewKnDynamicClient(fakeDynamic, "current"))
+	sources, err := listBuiltInSourceTypes(context.Background(), fake.CreateFakeKnDynamicClient("current"))
 	assert.NilError(t, err)
 	if sources == nil {
 		t.Fatal("sources = nil, want not nil")
@@ -94,14 +106,23 @@ func TestSourceListNoSourcesInstalled(t *testing.T) {
 	assert.Check(t, util.ContainsAll(err.Error(), "no sources", "found", "backend", "verify", "installation"))
 }
 
+func TestSourceListEmpty(t *testing.T) {
+	output, err := sourceFakeCmd([]string{"source", "list", "-o", "json"},
+		newSourceCRDObjWithSpec("pingsources", "sources.knative.dev", "v1beta2", "PingSource"),
+	)
+	assert.NilError(t, err)
+	outputJson := strings.Join(output[:], "\n")
+	assert.Assert(t, util.ContainsAll(outputJson, "\"apiVersion\": \"client.knative.dev/v1alpha1\"", "\"items\": [],", "\"kind\": \"SourceList\""))
+}
+
 func TestSourceList(t *testing.T) {
 	output, err := sourceFakeCmd([]string{"source", "list"},
-		newSourceCRDObjWithSpec("pingsources", "sources.knative.dev", "v1alpha1", "PingSource"),
-		newSourceCRDObjWithSpec("sinkbindings", "sources.knative.dev", "v1alpha1", "SinkBinding"),
-		newSourceCRDObjWithSpec("apiserversources", "sources.knative.dev", "v1alpha1", "ApiServerSource"),
-		newSourceUnstructuredObj("p1", "sources.knative.dev/v1alpha1", "PingSource"),
-		newSourceUnstructuredObj("s1", "sources.knative.dev/v1alpha1", "SinkBinding"),
-		newSourceUnstructuredObj("a1", "sources.knative.dev/v1alpha1", "ApiServerSource"),
+		newSourceCRDObjWithSpec("pingsources", "sources.knative.dev", "v1beta2", "PingSource"),
+		newSourceCRDObjWithSpec("sinkbindings", "sources.knative.dev", "v1", "SinkBinding"),
+		newSourceCRDObjWithSpec("apiserversources", "sources.knative.dev", "v1", "ApiServerSource"),
+		newSourceUnstructuredObj("p1", "sources.knative.dev/v1beta2", "PingSource"),
+		newSourceUnstructuredObj("s1", "sources.knative.dev/v1", "SinkBinding"),
+		newSourceUnstructuredObj("a1", "sources.knative.dev/v1", "ApiServerSource"),
 	)
 	assert.NilError(t, err)
 	assert.Check(t, util.ContainsAll(output[0], "NAME", "TYPE", "RESOURCE", "SINK", "READY"))
@@ -124,8 +145,8 @@ func TestSourceListUntyped(t *testing.T) {
 
 func TestSourceListNoHeaders(t *testing.T) {
 	output, err := sourceFakeCmd([]string{"source", "list", "--no-headers"},
-		newSourceCRDObjWithSpec("pingsources", "sources.knative.dev", "v1alpha1", "PingSource"),
-		newSourceUnstructuredObj("p1", "sources.knative.dev/v1alpha1", "PingSource"),
+		newSourceCRDObjWithSpec("pingsources", "sources.knative.dev", "v1beta2", "PingSource"),
+		newSourceUnstructuredObj("p1", "sources.knative.dev/v1beta2", "PingSource"),
 	)
 	assert.NilError(t, err)
 	assert.Check(t, util.ContainsNone(output[0], "NAME", "TYPE", "RESOURCE", "SINK", "READY"))
@@ -186,12 +207,12 @@ func newSourceUnstructuredObj(name, apiVersion, kind string) *unstructured.Unstr
 
 func TestSourceListAllNamespace(t *testing.T) {
 	output, err := sourceFakeCmd([]string{"source", "list", "--all-namespaces"},
-		newSourceCRDObjWithSpec("pingsources", "sources.knative.dev", "v1alpha1", "PingSource"),
-		newSourceCRDObjWithSpec("sinkbindings", "sources.knative.dev", "v1alpha1", "SinkBinding"),
-		newSourceCRDObjWithSpec("apiserversources", "sources.knative.dev", "v1alpha1", "ApiServerSource"),
-		newSourceUnstructuredObj("p1", "sources.knative.dev/v1alpha1", "PingSource"),
-		newSourceUnstructuredObj("s1", "sources.knative.dev/v1alpha1", "SinkBinding"),
-		newSourceUnstructuredObj("a1", "sources.knative.dev/v1alpha1", "ApiServerSource"),
+		newSourceCRDObjWithSpec("pingsources", "sources.knative.dev", "v1beta2", "PingSource"),
+		newSourceCRDObjWithSpec("sinkbindings", "sources.knative.dev", "v1", "SinkBinding"),
+		newSourceCRDObjWithSpec("apiserversources", "sources.knative.dev", "v1", "ApiServerSource"),
+		newSourceUnstructuredObj("p1", "sources.knative.dev/v1beta2", "PingSource"),
+		newSourceUnstructuredObj("s1", "sources.knative.dev/v1", "SinkBinding"),
+		newSourceUnstructuredObj("a1", "sources.knative.dev/v1", "ApiServerSource"),
 	)
 	assert.NilError(t, err)
 	assert.Check(t, util.ContainsAll(output[0], "NAMESPACE", "NAME", "TYPE", "RESOURCE", "SINK", "READY"))
