@@ -33,12 +33,20 @@ func TestDescribeRef(t *testing.T) {
 
 	pingRecorder := pingClient.Recorder()
 	pingRecorder.GetPingSource("testping",
-		createPingSource("testping", "*/2 * * * *", "test", "testsvc", map[string]string{"foo": "bar"}), nil)
+		createPingSource("testping", "*/2 * * * *", "test", "", "testsvc", map[string]string{"foo": "bar"}), nil)
 
 	out, err := executePingSourceCommand(pingClient, nil, "describe", "testping")
 	assert.NilError(t, err)
-	assert.Assert(t, util.ContainsAll(out, "*/2 * * * *", "test", "testsvc", "Service", "Overrides", "foo", "bar", "Conditions"))
+	assert.Assert(t, util.ContainsAll(out, "*/2 * * * *", "test", "testsvc", "Service", "Overrides", "foo", "bar", "Conditions", "Data:"))
+	assert.Assert(t, util.ContainsNone(out, "DataBase64"))
+	pingRecorder.Validate()
 
+	pingRecorder.GetPingSource("testping",
+		createPingSource("testping", "*/2 * * * *", "", "cGluZw==", "testsvc", map[string]string{"foo": "bar"}), nil)
+	out, err = executePingSourceCommand(pingClient, nil, "describe", "testping")
+	assert.NilError(t, err)
+	assert.Assert(t, util.ContainsAll(out, "*/2 * * * *", "test", "testsvc", "Service", "Overrides", "foo", "bar", "Conditions", "DataBase64"))
+	assert.Assert(t, util.ContainsNone(out, "Data:"))
 	pingRecorder.Validate()
 }
 
@@ -81,6 +89,13 @@ func TestDescribeError(t *testing.T) {
 
 }
 
+func TestPingDescribeErrorForNoArgs(t *testing.T) {
+	pingClient := clientv1beta2.NewMockKnPingSourceClient(t, "mynamespace")
+	out, err := executePingSourceCommand(pingClient, nil, "describe")
+	assert.ErrorContains(t, err, "single argument")
+	assert.Assert(t, util.ContainsAll(out, "requires", "single argument"))
+}
+
 func getPingSourceSinkURI() *sourcesv1beta.PingSource {
 	return &sourcesv1beta.PingSource{
 		TypeMeta: metav1.TypeMeta{
