@@ -18,7 +18,7 @@ import (
 	"testing"
 
 	"github.com/spf13/pflag"
-	"gotest.tools/assert"
+	"gotest.tools/v3/assert"
 )
 
 type boolPairTestCase struct {
