@@ -28,15 +28,18 @@ import (
 // PodSpecFlags to hold the container resource requirements values
 type PodSpecFlags struct {
 	// Direct field manipulation
-	Image   uniqueStringArg
-	Env     []string
-	EnvFrom []string
-	Mount   []string
-	Volume  []string
+	Image        uniqueStringArg
+	Env          []string
+	EnvFrom      []string
+	EnvValueFrom []string
+	Mount        []string
+	Volume       []string
 
-	Command string
+	Command []string
 	Arg     []string
 
+	ExtraContainers string
+
 	Resources          ResourceOptions
 	Port               string
 	ServiceAccountName string
@@ -82,6 +85,13 @@ func (p *PodSpecFlags) AddFlags(flagset *pflag.FlagSet) []string {
 			"To unset, specify the environment variable name followed by a \"-\" (e.g., NAME-).")
 	flagNames = append(flagNames, "env")
 
+	flagset.StringArrayVarP(&p.EnvValueFrom, "env-value-from", "", []string{},
+		"Add environment variable from a value of key in ConfigMap (prefix cm: or config-map:) or a Secret (prefix sc: or secret:). "+
+			"Example: --env-value-from NAME=cm:myconfigmap:key or --env-value-from NAME=secret:mysecret:key. "+
+			"You can use this flag multiple times. "+
+			"To unset a value from a ConfigMap/Secret key reference, append \"-\" to the key, e.g. --env-value-from ENV-.")
+	flagNames = append(flagNames, "env-value-from")
+
 	flagset.StringArrayVarP(&p.EnvFrom, "env-from", "", []string{},
 		"Add environment variables from a ConfigMap (prefix cm: or config-map:) or a Secret (prefix secret:). "+
 			"Example: --env-from cm:myconfigmap or --env-from secret:mysecret. "+
@@ -104,9 +114,9 @@ func (p *PodSpecFlags) AddFlags(flagset *pflag.FlagSet) []string {
 			"To unset a ConfigMap/Secret reference, append \"-\" to the name, e.g. --volume myvolume-.")
 	flagNames = append(flagNames, "volume")
 
-	flagset.StringVarP(&p.Command, "cmd", "", "",
+	flagset.StringArrayVarP(&p.Command, "cmd", "", []string{},
 		"Specify command to be used as entrypoint instead of default one. "+
-			"Example: --cmd /app/start or --cmd /app/start --arg myArg to pass additional arguments.")
+			"Example: --cmd /app/start or --cmd sh --cmd /app/start.sh or --cmd /app/start --arg myArg to pass additional arguments.")
 	flagNames = append(flagNames, "cmd")
 
 	flagset.StringArrayVarP(&p.Arg, "arg", "", []string{},
@@ -115,6 +125,11 @@ func (p *PodSpecFlags) AddFlags(flagset *pflag.FlagSet) []string {
 			"You can use this flag multiple times.")
 	flagNames = append(flagNames, "arg")
 
+	flagset.StringVarP(&p.ExtraContainers, "extra-containers", "", "",
+		"Specify path to file including definition for additional containers, alternatively use '-' to read from stdin. "+
+			"Example: --extra-containers ./containers.yaml or --extra-containers -.")
+	flagNames = append(flagNames, "containers")
+
 	flagset.StringSliceVar(&p.Resources.Limits,
 		"limit",
 		nil,
@@ -150,17 +165,22 @@ func (p *PodSpecFlags) AddFlags(flagset *pflag.FlagSet) []string {
 	return flagNames
 }
 
-// ResolvePodSpec will create corev1.PodSpec based on the flag inputs
-func (p *PodSpecFlags) ResolvePodSpec(podSpec *corev1.PodSpec, flags *pflag.FlagSet) error {
+// ResolvePodSpec will create corev1.PodSpec based on the flag inputs and all input arguments
+func (p *PodSpecFlags) ResolvePodSpec(podSpec *corev1.PodSpec, flags *pflag.FlagSet, allArgs []string) error {
 	var err error
-	if flags.Changed("env") {
-		envMap, err := util.MapFromArrayAllowingSingles(p.Env, "=")
+
+	if flags.Changed("env") || flags.Changed("env-value-from") {
+		envToUpdate, envToRemove, err := util.OrderedMapAndRemovalListFromArray(p.Env, "=")
 		if err != nil {
 			return fmt.Errorf("Invalid --env: %w", err)
 		}
 
-		envToRemove := util.ParseMinusSuffix(envMap)
-		err = UpdateEnvVars(podSpec, envMap, envToRemove)
+		envValueFromToUpdate, envValueFromToRemove, err := util.OrderedMapAndRemovalListFromArray(p.EnvValueFrom, "=")
+		if err != nil {
+			return fmt.Errorf("Invalid --env-value-from: %w", err)
+		}
+
+		err = UpdateEnvVars(podSpec, allArgs, envToUpdate, envToRemove, envValueFromToUpdate, envValueFromToRemove)
 		if err != nil {
 			return err
 		}
@@ -255,5 +275,14 @@ func (p *PodSpecFlags) ResolvePodSpec(podSpec *corev1.PodSpec, flags *pflag.Flag
 		}
 	}
 
+	if flags.Changed("extra-containers") || p.ExtraContainers == "-" {
+		var fromFile *corev1.PodSpec
+		fromFile, err = decodeContainersFromFile(p.ExtraContainers)
+		if err != nil {
+			return err
+		}
+		UpdateContainers(podSpec, fromFile.Containers)
+	}
+
 	return nil
 }
