@@ -16,10 +16,12 @@ package flags
 
 import (
 	"fmt"
-	"sort"
+	"os"
 	"strconv"
 	"strings"
 
+	"k8s.io/apimachinery/pkg/util/yaml"
+
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/util/sets"
 	"knative.dev/client/pkg/util"
@@ -53,20 +55,60 @@ func containerOfPodSpec(spec *corev1.PodSpec) *corev1.Container {
 
 // UpdateEnvVars gives the configuration all the env var values listed in the given map of
 // vars.  Does not touch any environment variables not mentioned, but it can add
-// new env vars and change the values of existing ones, then sort by env key name.
-func UpdateEnvVars(spec *corev1.PodSpec, toUpdate map[string]string, toRemove []string) error {
+// new env vars and change the values of existing ones.
+func UpdateEnvVars(spec *corev1.PodSpec,
+	allArgs []string, envToUpdate *util.OrderedMap, envToRemove []string, envValueFromToUpdate *util.OrderedMap, envValueFromToRemove []string) error {
 	container := containerOfPodSpec(spec)
-	updated := updateEnvVarsFromMap(container.Env, toUpdate)
-	updated = removeEnvVars(updated, toRemove)
-	// Sort by env key name
-	sort.SliceStable(updated, func(i, j int) bool {
-		return updated[i].Name < updated[j].Name
-	})
+
+	allEnvsToUpdate := util.NewOrderedMap()
+
+	envIterator := envToUpdate.Iterator()
+	envValueFromIterator := envValueFromToUpdate.Iterator()
+
+	envKey, envValue, envExists := envIterator.NextString()
+	envValueFromKey, envValueFromValue, envValueFromExists := envValueFromIterator.NextString()
+	for _, arg := range allArgs {
+		// envs are stored as NAME=value
+		if envExists && isValidEnvArg(arg, envKey, envValue) {
+			allEnvsToUpdate.Set(envKey, corev1.EnvVar{
+				Name:  envKey,
+				Value: envValue,
+			})
+			envKey, envValue, envExists = envIterator.NextString()
+		} else if envValueFromExists && isValidEnvValueFromArg(arg, envValueFromKey, envValueFromValue) {
+			// envs are stored as NAME=secret:sercretName:key or NAME=config-map:cmName:key
+			envVarSource, err := createEnvVarSource(envValueFromValue)
+			if err != nil {
+				return err
+			}
+			allEnvsToUpdate.Set(envValueFromKey, corev1.EnvVar{
+				Name:      envValueFromKey,
+				ValueFrom: envVarSource,
+			})
+			envValueFromKey, envValueFromValue, envValueFromExists = envValueFromIterator.NextString()
+		}
+	}
+
+	updated := updateEnvVarsFromMap(container.Env, allEnvsToUpdate)
+	updated = removeEnvVars(updated, append(envToRemove, envValueFromToRemove...))
+
 	container.Env = updated
 
 	return nil
 }
 
+// isValidEnvArg checks that the input arg is a valid argument for specifying env value,
+// ie. stored as NAME=value
+func isValidEnvArg(arg, envKey, envValue string) bool {
+	return strings.HasPrefix(arg, envKey+"="+envValue) || strings.HasPrefix(arg, "-e="+envKey+"="+envValue) || strings.HasPrefix(arg, "--env="+envKey+"="+envValue)
+}
+
+// isValidEnvValueFromArg checks that the input arg is a valid argument for specifying env from value,
+// ie. stored as NAME=secret:sercretName:key or NAME=config-map:cmName:key
+func isValidEnvValueFromArg(arg, envValueFromKey, envValueFromValue string) bool {
+	return strings.HasPrefix(arg, envValueFromKey+"="+envValueFromValue) || strings.HasPrefix(arg, "--env-value-from="+envValueFromKey+"="+envValueFromValue)
+}
+
 // UpdateEnvFrom updates envFrom
 func UpdateEnvFrom(spec *corev1.PodSpec, toUpdate []string, toRemove []string) error {
 	container := containerOfPodSpec(spec)
@@ -115,9 +157,9 @@ func UpdateImage(spec *corev1.PodSpec, image string) error {
 }
 
 // UpdateContainerCommand updates container with a given argument
-func UpdateContainerCommand(spec *corev1.PodSpec, command string) error {
+func UpdateContainerCommand(spec *corev1.PodSpec, command []string) error {
 	container := containerOfPodSpec(spec)
-	container.Command = []string{command}
+	container.Command = command
 	return nil
 }
 
@@ -216,19 +258,45 @@ func UpdateImagePullSecrets(spec *corev1.PodSpec, pullsecrets string) {
 	}
 }
 
-// =======================================================================================
-func updateEnvVarsFromMap(env []corev1.EnvVar, toUpdate map[string]string) []corev1.EnvVar {
-	set := sets.NewString()
-	for i := range env {
-		envVar := &env[i]
-		if val, ok := toUpdate[envVar.Name]; ok {
-			envVar.Value = val
-			set.Insert(envVar.Name)
+// UpdateContainers updates the containers array with additional ones provided from file or os.Stdin
+func UpdateContainers(spec *corev1.PodSpec, containers []corev1.Container) {
+	var matched []string
+	if len(spec.Containers) == 1 {
+		spec.Containers = append(spec.Containers, containers...)
+	} else {
+		for i, container := range spec.Containers {
+			for j, toUpdate := range containers {
+				if container.Name == toUpdate.Name {
+
+					spec.Containers[i] = containers[j]
+
+					matched = append(matched, toUpdate.Name)
+				}
+			}
+		}
+		for _, container := range containers {
+			if !util.SliceContainsIgnoreCase(matched, container.Name) {
+				spec.Containers = append(spec.Containers, container)
+			}
 		}
 	}
-	for name, val := range toUpdate {
-		if !set.Has(name) {
-			env = append(env, corev1.EnvVar{Name: name, Value: val})
+}
+
+// =======================================================================================
+func updateEnvVarsFromMap(env []corev1.EnvVar, toUpdate *util.OrderedMap) []corev1.EnvVar {
+	updated := sets.NewString()
+
+	for i := range env {
+		object, present := toUpdate.Get(env[i].Name)
+		if present {
+			env[i] = object.(corev1.EnvVar)
+			updated.Insert(env[i].Name)
+		}
+	}
+	it := toUpdate.Iterator()
+	for name, envVar, ok := it.Next(); ok; name, envVar, ok = it.Next() {
+		if !updated.Has(name) {
+			env = append(env, envVar.(corev1.EnvVar))
 		}
 	}
 	return env
@@ -246,6 +314,50 @@ func removeEnvVars(env []corev1.EnvVar, toRemove []string) []corev1.EnvVar {
 	return env
 }
 
+func createEnvVarSource(spec string) (*corev1.EnvVarSource, error) {
+	slices := strings.SplitN(spec, ":", 3)
+	if len(slices) != 3 {
+		return nil, fmt.Errorf("argument requires a value in form \"resourceType:name:key\" where \"resourceType\" can be one of \"config-map\" (\"cm\") or \"secret\" (\"sc\"); got %q", spec)
+	}
+
+	typeString := strings.TrimSpace(slices[0])
+	sourceName := strings.TrimSpace(slices[1])
+	sourceKey := strings.TrimSpace(slices[2])
+
+	var sourceType string
+	envVarSource := corev1.EnvVarSource{}
+
+	switch typeString {
+	case "config-map", "cm":
+		sourceType = "ConfigMap"
+		envVarSource.ConfigMapKeyRef = &corev1.ConfigMapKeySelector{
+			LocalObjectReference: corev1.LocalObjectReference{
+				Name: sourceName,
+			},
+			Key: sourceKey}
+	case "secret", "sc":
+		sourceType = "Secret"
+		envVarSource.SecretKeyRef = &corev1.SecretKeySelector{
+			LocalObjectReference: corev1.LocalObjectReference{
+				Name: sourceName,
+			},
+			Key: sourceKey}
+	default:
+		return nil, fmt.Errorf("unsupported env source type \"%q\"; supported source types are \"config-map\" (\"cm\") and \"secret\" (\"sc\")", slices[0])
+	}
+
+	if len(sourceName) == 0 {
+		return nil, fmt.Errorf("the name of %s cannot be an empty string", sourceType)
+	}
+
+	if len(sourceKey) == 0 {
+		return nil, fmt.Errorf("the key referenced by resource %s \"%s\" cannot be an empty string", sourceType, sourceName)
+	}
+
+	return &envVarSource, nil
+}
+
+// =======================================================================================
 func updateEnvFrom(envFromSources []corev1.EnvFromSource, toUpdate []string) ([]corev1.EnvFromSource, error) {
 	existingNameSet := make(map[string]bool)
 
@@ -553,3 +665,22 @@ func reviseVolumesToRemove(volumeMounts []corev1.VolumeMount, volumesToRemove []
 	}
 	return volumesToRemove
 }
+
+func decodeContainersFromFile(filename string) (*corev1.PodSpec, error) {
+	var f *os.File
+	var err error
+	if filename == "-" {
+		f = os.Stdin
+	} else {
+		f, err = os.Open(filename)
+		if err != nil {
+			return nil, err
+		}
+	}
+	podSpec := &corev1.PodSpec{}
+	decoder := yaml.NewYAMLOrJSONDecoder(f, 512)
+	if err = decoder.Decode(podSpec); err != nil {
+		return nil, err
+	}
+	return podSpec, nil
+}
