@@ -15,6 +15,7 @@
 package plugin
 
 import (
+	"errors"
 	"fmt"
 	"io/ioutil"
 	"os"
@@ -26,7 +27,6 @@ import (
 	"text/template"
 
 	homedir "github.com/mitchellh/go-homedir"
-	"github.com/pkg/errors"
 	"github.com/spf13/cobra"
 )
 
@@ -52,6 +52,26 @@ type Plugin interface {
 	Path() string
 }
 
+type ContextData map[string]string
+
+type PluginManifest struct {
+	// ProducesContextDataKeys is a list of keys for the ContextData that
+	// a plugin can produce. Nil or an empty list declares that this
+	// plugin is not ContextDataProducer
+	ProducesContextDataKeys []string
+
+	// ConsumesContextDataKeys is a list of keys from a ContextData that a
+	// plugin is interested in to consume. Nil or an empty list declares
+	// that this plugin is not a ContextDataConsumer
+	ConsumesContextDataKeys []string
+}
+
+type ContextDataConsumer interface {
+	// ExecuteWithContextData executes the plugin with the given args much like
+	// Execute() but with an additional argument that holds the ContextData
+	ExecuteWithContextData(args []string, data ContextData) error
+}
+
 type Manager struct {
 	// Dedicated plugin directory as configured
 	pluginsDir string
@@ -232,6 +252,7 @@ func (manager *Manager) LookupInPath() bool {
 
 // Execute the plugin with the given arguments
 func (plugin *plugin) Execute(args []string) error {
+	//nolint:gosec // Passing the arguments through is expected, the plugins are trusted.
 	cmd := exec.Command(plugin.path, args...)
 	cmd.Stdout = os.Stdout
 	cmd.Stderr = os.Stderr
@@ -380,6 +401,11 @@ func findMostSpecificPluginInPath(dir string, parts []string, lookupInPath bool)
 		var nameParts []string
 		var commandParts []string
 		for _, p := range parts[0:i] {
+			// for arguments that contain the path separator,
+			// stop the loop once the separator appears
+			if strings.Contains(p, string(os.PathSeparator)) {
+				break
+			}
 			// Subcommands with "-" are translated to "_"
 			// (e.g. a command  "kn log-all" is translated to a plugin "kn-log_all")
 			nameParts = append(nameParts, convertDashToUnderscore(p))
@@ -390,7 +416,7 @@ func findMostSpecificPluginInPath(dir string, parts []string, lookupInPath bool)
 		// Check for the name in plugin directory and PATH (if requested)
 		path, err := findInDirOrPath(name, dir, lookupInPath)
 		if err != nil {
-			return nil, errors.Wrap(err, fmt.Sprintf("cannot lookup plugin %s in directory %s (lookup in path: %t)", name, dir, lookupInPath))
+			return nil, fmt.Errorf("cannot lookup plugin %s in directory %s (lookup in path: %t): %w", name, dir, lookupInPath, err)
 		}
 
 		// Found, return it
@@ -440,7 +466,7 @@ func findInDirOrPath(name string, dir string, lookupInPath bool) (string, error)
 			return path, nil
 		}
 		if !os.IsNotExist(err) {
-			return "", errors.Wrap(err, fmt.Sprintf("i/o error while reading %s", path))
+			return "", fmt.Errorf("i/o error while reading %s: %w", path, err)
 		}
 
 		// Check in PATH if requested
@@ -450,8 +476,8 @@ func findInDirOrPath(name string, dir string, lookupInPath bool) (string, error)
 				// Found in path
 				return path, nil
 			}
-			if execErr, ok := err.(*exec.Error); !ok || execErr.Unwrap() != exec.ErrNotFound {
-				return "", errors.Wrap(err, fmt.Sprintf("error for looking up %s in path", name))
+			if !errors.Is(err, exec.ErrNotFound) {
+				return "", fmt.Errorf("error for looking up %s in path: %w", name, err)
 			}
 		}
 	}
