@@ -19,7 +19,7 @@ import (
 	"strconv"
 	"testing"
 
-	"gotest.tools/assert"
+	"gotest.tools/v3/assert"
 
 	"knative.dev/pkg/ptr"
 	"knative.dev/serving/pkg/apis/autoscaling"
@@ -79,7 +79,7 @@ type userImageAnnotCase struct {
 	set    bool
 }
 
-func TestSetUserImageAnnot(t *testing.T) {
+func TestSetUserImageAnnotation(t *testing.T) {
 	cases := []userImageAnnotCase{
 		{"foo/bar", "", "foo/bar", true},
 		{"foo/bar@sha256:asdfsf", "", "foo/bar@sha256:asdfsf", true},
@@ -99,23 +99,52 @@ func TestSetUserImageAnnot(t *testing.T) {
 		}
 		container.Image = c.image
 		if c.set {
-			SetUserImageAnnot(template)
+			UpdateUserImageAnnotation(template)
 		} else {
-			UnsetUserImageAnnot(template)
+			UnsetUserImageAnnotation(template)
 		}
 		assert.Equal(t, template.Annotations[UserImageAnnotationKey], c.result)
 	}
 }
 
-func TestFreezeImageToDigest(t *testing.T) {
+func TestPinImageToDigest(t *testing.T) {
 	template, container := getRevisionTemplate()
 	revision := &servingv1.Revision{}
 	revision.Spec = template.Spec
 	revision.ObjectMeta = template.ObjectMeta
-	revision.Status.DeprecatedImageDigest = "gcr.io/foo/bar@sha256:deadbeef"
+	revision.Status.ContainerStatuses = []servingv1.ContainerStatus{
+		{Name: "user-container", ImageDigest: "gcr.io/foo/bar@sha256:deadbeef"},
+	}
 	container.Image = "gcr.io/foo/bar:latest"
-	FreezeImageToDigest(template, revision)
+	err := PinImageToDigest(template, revision)
+	assert.NilError(t, err)
 	assert.Equal(t, container.Image, "gcr.io/foo/bar@sha256:deadbeef")
+
+	// No base revision --> no-op
+	err = PinImageToDigest(template, nil)
+	assert.NilError(t, err)
+}
+
+func TestPinImageToDigestInvalidImages(t *testing.T) {
+	template, container := getRevisionTemplate()
+	container.Image = "gcr.io/A"
+	revision := &servingv1.Revision{
+		Spec: servingv1.RevisionSpec{
+			PodSpec: corev1.PodSpec{
+				Containers: []corev1.Container{
+					{Image: "gcr.io/B"},
+				},
+			},
+		},
+	}
+	err := PinImageToDigest(template, revision)
+	assert.ErrorContains(t, err, "unexpected image")
+}
+
+func TestUpdateTimestampAnnotation(t *testing.T) {
+	template, _ := getRevisionTemplate()
+	UpdateTimestampAnnotation(template)
+	assert.Assert(t, template.Annotations[UpdateTimestampAnnotationKey] != "")
 }
 
 func TestUpdateMinScale(t *testing.T) {
@@ -382,6 +411,13 @@ func TestUpdateAnnotationsRemoveExisting(t *testing.T) {
 	assert.DeepEqual(t, expected, actual)
 }
 
+func TestString(t *testing.T) {
+	vt := ConfigMapVolumeSourceType
+	assert.Equal(t, "config-map", vt.String())
+	vt = -1
+	assert.Equal(t, "unknown", vt.String())
+}
+
 //
 // =========================================================================================================
 
