@@ -22,10 +22,11 @@ import (
 	"strings"
 	"testing"
 
-	"gotest.tools/assert"
+	"gotest.tools/v3/assert"
 
 	"knative.dev/client/lib/test"
 	"knative.dev/client/pkg/util"
+	network "knative.dev/networking/pkg"
 	pkgtest "knative.dev/pkg/test"
 	"knative.dev/serving/pkg/apis/serving"
 )
@@ -79,7 +80,7 @@ func serviceCreatePrivate(r *test.KnRunResultCollector, serviceName string) {
 
 	out = r.KnTest().Kn().Run("service", "describe", serviceName, "--verbose")
 	r.AssertNoError(out)
-	assert.Check(r.T(), util.ContainsAllIgnoreCase(out.Stdout, serving.VisibilityLabelKey, serving.VisibilityClusterLocal))
+	assert.Check(r.T(), util.ContainsAllIgnoreCase(out.Stdout, network.VisibilityLabelKey, serving.VisibilityClusterLocal))
 }
 
 func serviceCreatePrivateUpdatePublic(r *test.KnRunResultCollector, serviceName string) {
@@ -90,16 +91,15 @@ func serviceCreatePrivateUpdatePublic(r *test.KnRunResultCollector, serviceName
 
 	out = r.KnTest().Kn().Run("service", "describe", serviceName, "--verbose")
 	r.AssertNoError(out)
-	assert.Check(r.T(), util.ContainsAllIgnoreCase(out.Stdout, serving.VisibilityLabelKey, serving.VisibilityClusterLocal))
+	assert.Check(r.T(), util.ContainsAllIgnoreCase(out.Stdout, network.VisibilityLabelKey, serving.VisibilityClusterLocal))
 
-	out = r.KnTest().Kn().Run("service", "update", serviceName,
-		"--image", pkgtest.ImagePath("helloworld"), "--no-cluster-local")
+	out = r.KnTest().Kn().Run("service", "update", serviceName, "--no-cluster-local")
 	r.AssertNoError(out)
-	assert.Check(r.T(), util.ContainsAllIgnoreCase(out.Stdout, "service", serviceName, "updated", "namespace", r.KnTest().Kn().Namespace(), "ready"))
+	assert.Check(r.T(), util.ContainsAllIgnoreCase(out.Stdout, "service", serviceName, "no new revision", "namespace", r.KnTest().Kn().Namespace()))
 
 	out = r.KnTest().Kn().Run("service", "describe", serviceName, "--verbose")
 	r.AssertNoError(out)
-	assert.Check(r.T(), util.ContainsNone(out.Stdout, serving.VisibilityLabelKey, serving.VisibilityClusterLocal))
+	assert.Check(r.T(), util.ContainsNone(out.Stdout, network.VisibilityLabelKey, serving.VisibilityClusterLocal))
 }
 
 func serviceCreateDuplicate(r *test.KnRunResultCollector, serviceName string) {
@@ -146,7 +146,7 @@ func serviceMultipleDelete(r *test.KnRunResultCollector, existService, nonexistS
 }
 
 func serviceUntagTagThatDoesNotExist(r *test.KnRunResultCollector, serviceName string) {
-	out := r.KnTest().Kn().Run("service", "list", serviceName)
+	out := r.KnTest().Kn().Run("ksvc", "ls", serviceName)
 	r.AssertNoError(out)
 	assert.Check(r.T(), strings.Contains(out.Stdout, serviceName), "Service "+serviceName+" does not exist for test (but should exist)")
 
@@ -155,17 +155,17 @@ func serviceUntagTagThatDoesNotExist(r *test.KnRunResultCollector, serviceName s
 }
 
 func serviceDeleteAll(r *test.KnRunResultCollector) {
-	out := r.KnTest().Kn().Run("service", "list")
+	out := r.KnTest().Kn().Run("services", "ls")
 	r.AssertNoError(out)
 	// Check if services created successfully/available for test.
 	assert.Check(r.T(), !strings.Contains(out.Stdout, "No services found."), "No services created for kn service delete --all e2e (but should exist)")
 
-	out = r.KnTest().Kn().Run("service", "delete", "--all")
+	out = r.KnTest().Kn().Run("services", "delete", "--all")
 	r.AssertNoError(out)
 	// Check if output contains successfully deleted to verify deletion took place.
 	assert.Check(r.T(), strings.Contains(out.Stdout, "successfully deleted"), "Failed to get 'successfully deleted' message")
 
-	out = r.KnTest().Kn().Run("service", "list")
+	out = r.KnTest().Kn().Run("services", "list")
 	r.AssertNoError(out)
 	// Check if no services present after kn service delete --all.
 	assert.Check(r.T(), strings.Contains(out.Stdout, "No services found."), "Failed to show 'No services found' after kn service delete --all")
